@@ -102,5 +102,20 @@ define ([
             }
         }); // viewIntervalsDrowselect
 
+        target.push('viewLocksDrowselect', {
+            'name': 'viewLocksDrowselect',
+            'type': 'drowselect',
+            'menuText': 'View',
+            'title': 'Lock list',
+            'preamble': null,
+            'aclProfile': 'passerby',
+            'entriesRead': [
+                entries.lOintvl, entries.lOlid,
+            ],
+            'miniMenu': {
+                entries: ['deleteLock'],
+            }
+        }); // viewLocksDrowselect
+
     };
 });
